@@ -3,6 +3,7 @@ from requests import get
 from bs4 import BeautifulSoup
 from argparse import ArgumentParser
 from pyperclip import copy as clipboard_copy
+from pubchempy import get_compounds
 from selenium.webdriver.common.by import By
 
 from WikiFiller.lib.Browser import Browser
@@ -28,33 +29,50 @@ def main():
         exit()
 
     url = f'https://pubchem.ncbi.nlm.nih.gov/compound/{argv.name}'
-    browser_driver = Browser()
-    browser_driver.driver.get(url)
+    #browser_driver = Browser()
+    #browser_driver.driver.get(url)
 
     compound_data = BeautifulSoup(get(url).text, 'html.parser')
     title = compound_data.find_all("meta", {"property":"og:title"})[0].attrs['content']
-    pubchem_cid = compound_data.find_all("meta", {"property":"og:url"})[0].attrs['content'].split('/')[-1]
-    iupac = browser_driver.find_element_by_id(By.ID,"IUPAC-Name")
-    inchi_full = browser_driver.find_element_by_id(By.ID,"InChI")
-    inchi = inchi_full.split('=')[-1]
-    inchi_key = browser_driver.find_element_by_id(By.ID,"InChI-Key")
-    smiles = browser_driver.find_element_by_id(By.ID,"Canonical-SMILES")
-    cas_no = browser_driver.find_element_by_id(By.ID,"CAS")
-    ec_no = browser_driver.find_element_by_id(By.ID,"European-Community-(EC)-Number")
-    unii = browser_driver.find_element_by_id(By.ID,"UNII")
-    molecular_formula = fix_molecular(browser_driver.find_element_by_id(By.ID,"Molecular-Formula").upper())
-    wiki_formula = wiki_molecular(molecular_formula)
-    mesh_names = browser_driver.find_element_by_id(By.ID,"MeSH-Entry-Terms", first=False)
-    depositor_names = browser_driver.find_element_by_id(By.ID,"Depositor-Supplied-Synonyms", first=False)
-    other_1, chembl = "", ""
-    chemspider = chemspider_fetch(argv.name) or chemspider_fetch(title) or chemspider_fetch(smiles)
-    chebi = chebi_fetch(argv.name) or chebi_fetch(title) or chebi_fetch(inchi_full)
-    UNUSED = [mesh_names, depositor_names]
+    print(f"Creating article template on: {title}")
+    compound = get_compounds(argv.name, 'name')[0]
+    pubchem_cid = compound.cid
+    iupac = compound.iupac_name
+    inchi = compound.inchi
+    inchi_key = compound.inchikey
+    smiles = compound.canonical_smiles
+    molecular_formula = fix_molecular(compound.molecular_formula.upper())
+    wiki_formula = wiki_moecular(molecular_formula)
+    mesh_names = []
+    depositor_names = compound.synonyms
 
-    browser_driver.driver.quit()
+    #pubchem_cid = compound_data.find_all("meta", {"property":"og:url"})[0].attrs['content'].split('/')[-1]
+    #iupac = browser_driver.find_element_by_id(By.ID,"IUPAC-Name")
+    #inchi_full = browser_driver.find_element_by_id(By.ID,"InChI")
+    #inchi = inchi_full.split('=')[-1]
+    #inchi_key = browser_driver.find_element_by_id(By.ID,"InChI-Key")
+    #smiles = browser_driver.find_element_by_id(By.ID,"Canonical-SMILES")
+    cas_no = "" #browser_driver.find_element_by_id(By.ID,"CAS")
+    ec_no = ""  #browser_driver.find_element_by_id(By.ID,"European-Community-(EC)-Number")
+    unii = ""   #browser_driver.find_element_by_id(By.ID,"UNII")
+    #molecular_formula = fix_molecular(browser_driver.find_element_by_id(By.ID,"Molecular-Formula").upper())
+    #wiki_formula = wiki_molecular(molecular_formula)
+    #mesh_names = browser_driver.find_element_by_id(By.ID,"MeSH-Entry-Terms", first=False)
+    #depositor_names = browser_driver.find_element_by_id(By.ID,"Depositor-Supplied-Synonyms", first=False)
+
+    other_names = [x for x in depositor_names if not any(map(str.isdigit, str(x))) and not '-' in x and not 'pubchem' in x.lower()]
+    other_names.extend([x for x in mesh_names if not any(map(str.isdigit, str(x))) and not '-' in x and not 'mesh' in x.lower()])
+    other_names = list(set(other_names))
+    alt_titles = other_names.copy()
+    other_names = ("\n | ".join(other_names)) if other_names else ""
+    chembl = ""
+    chemspider = chemspider_fetch(argv.name) or chemspider_fetch(title) or chemspider_fetch(smiles) or [holder for alt_title in alt_titles if (holder := chemspider_fetch(alt_title))][0]
+    chebi = chebi_fetch(argv.name) or chebi_fetch(title) or chebi_fetch(inchi_full) or [holder for alt_title in alt_titles if (holder := chebi_fetch(alt_title))][0]
+
+    #browser_driver.driver.quit()
 
     if argv.chembox:
-        chembox_1 = chembox_part_1 % (iupac, other_1)
+        chembox_1 = chembox_part_1 % (iupac, other_names)
         chembox_2 = chembox_part_2 % (cas_no, chemspider, chebi, chembl, ec_no, inchi, inchi_key, smiles, pubchem_cid, unii)
         chembox_3 = chembox_part_3 % (wiki_formula, title)
         if argv.category:
@@ -77,8 +95,6 @@ def main():
     if argv.output:
         with open(argv.output, 'w+') as f:
             f.write(full_chembox_template)
-    #print("Synonyms")
-    #print(mesh_names, depositor_names)
 
 if __name__ == '__main__':
     main()
