@@ -15,7 +15,6 @@ def get_name_from_cid(cid):
     return title
 
 def change_molecular(molecular_list: list, atom_changes: list = []) -> list:
-    #""" C2 H6 O , ["+O1"] """ fix
     if not atom_changes:
         changed_list = ["".join(changable) for changable in molecular_list]
         return changed_list
@@ -24,12 +23,20 @@ def change_molecular(molecular_list: list, atom_changes: list = []) -> list:
     for atom_change in atom_changes:
         atom_type, atom_name, atom_number = atom_change[0], atom_change[1], atom_change[2]
         if atom_type == "+":
-            new_atom_number = str(int(atom_dict[atom_name]) + int(atom_number))
-            atom_dict[atom_name] = new_atom_number
+            if atom_name in atom_dict:
+                new_atom_number = str(int(atom_dict[atom_name]) + int(atom_number))
+                atom_dict[atom_name] = new_atom_number
+            else:
+                new_atom_number = str(atom_number)
+                atom_dict[atom_name] = new_atom_number
         elif atom_type == "_":
             new_atom_number = str(int(atom_dict[atom_name]) - int(atom_number))
             atom_dict[atom_name] = new_atom_number
-    new_list = ["".join(l) for l in list(atom_dict.items())]
+    atom_dict = dict(sorted(atom_dict.items()))
+    new_list = []
+    for a,n in list(atom_dict.items()):
+        joined = "".join((a,n)) if int(n) != 1 else a
+        new_list.append(joined)
     return new_list
 
 def fix_molecular(formula: str) -> list:
@@ -63,7 +70,6 @@ def fix_molecular(formula: str) -> list:
     return new_start
 
 def get_smiles_from_nist(url):
-    print(f"Getting inchi of {url}")
     if not url:
         return url
     r = BeautifulSoup(get(url).text, 'html.parser')
@@ -98,7 +104,11 @@ def molecular_formula_fetch_nist(molecular_formula: str) -> dict:
     #compounds = [print(elem, type(elem)) for elem in r.find_all('ol')]
     compounds = [elem.findChildren("a") for elem in r.find_all('ol')][0]
     """ Change into threads later """
-    links = {compound.string: get_smiles_from_nist(f"https://webbook.nist.gov{compound['href']}") for compound in compounds}
+    with ThreadPoolExecutor(max_workers=20) as executor:
+        future_objects = [executor.submit(get_smiles_from_nist, f"https://webbook.nist.gov{compound['href']}") for compound in compounds]
+    smiles = [future_object.result() for future_object in future_objects]
+    names = [compound.string for compound in compounds]
+    links = dict(zip(names, smiles))
     return links
         #print(elem)
         #print(type(elem.findChildren("a")))
